@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceConfig|
-|''Version''|0.6.2|
+|''Version''|0.6.3|
 |''Description''|TiddlySpace configuration|
 |''Status''|stable|
 |''Source''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/TiddlySpaceConfig.js|
@@ -71,7 +71,9 @@ sssp.removeTiddlerCallback = function(context, userParams) {
 		context.workspace = "recipes/" + recipe;
 		var callback = function(context, userParams) {
 			if(context.status) {
+				var dirty = store.isDirty();
 				store.saveTiddler(context.tiddler);
+				store.setDirty(dirty);
 			} else {
 				store.notify(title, true);
 			}
